@@ -1,6 +1,6 @@
 package Map::Tube::NYC::Line::INDEighthAvenue;
 
-$Map::Tube::NYC::Line::INDEighthAvenue::VERSION   = '0.17';
+$Map::Tube::NYC::Line::INDEighthAvenue::VERSION   = '0.18';
 $Map::Tube::NYC::Line::INDEighthAvenue::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::NYC::Line::INDEighthAvenue - NYC Subway: IND Eighth Avenue Line stati
 
 =head1 VERSION
 
-Version 0.17
+Version 0.18
 
 =head1 DESCRIPTION
 
@@ -76,14 +76,14 @@ NYC Subway: IND Eighth Avenue Line stations.
 
 =head1 MAP
 
-NYC Subway Map: L<IND Eighth Avenue Line|https://raw.githubusercontent.com/Manwar/Map-Tube-NYC/master/maps/IND-Eighth-Avenue.png>
+NYC Subway: L<IND Eighth Avenue Line|https://raw.githubusercontent.com/Manwar/Map-Tube-NYC/master/maps/IND-Eighth-Avenue.png>
 map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
 <a href = "https://raw.githubusercontent.com/Manwar/Map-Tube-NYC/master/maps/IND-Eighth-Avenue.png">
 <img src    = "https://raw.githubusercontent.com/Manwar/Map-Tube-NYC/master/maps/IND-Eighth-Avenue.png"
-     alt    = "NYC Subway Map: IND Eighth Avenue Line"
+     alt    = "NYC Subway: IND Eighth Avenue Line"
      width  = "300px"
      height = "600px"/>
 </a>
